.. _interpretation:

Data interpretation
===================

.. todo::

   The interpretation tutorial. (Probably to be written by Josephine).
   It should cover e.g., additional methods to validate the results (literature, survival analysis, differential CNVs).

